Struct soundio_sys::SoundIoChannelArea[][src]

#[repr(C)]
pub struct SoundIoChannelArea { pub ptr: *mut c_char, pub step: c_int, }
The size of this struct is OK to use.

Fields

ptr: *mut c_char

Base address of buffer.

step: c_int

How many bytes it takes to get from the beginning of one sample to the beginning of the next sample.