Struct soundio_sys::SoundIoChannelArea [−][src]
The size of this struct is OK to use.
Fields
ptr: *mut c_charBase address of buffer.
step: c_intHow many bytes it takes to get from the beginning of one sample to the beginning of the next sample.