Type Definition soundio_sys::SoundIoFormat [−][src]
pub type SoundIoFormat = c_uint;Expand description
For your convenience, Native Endian and Foreign Endian constants are defined which point to the respective SoundIoFormat values.